@@ -1,4 +1,4 @@
-import zipfile
+import zipfile_xz as zipfile
 
 class ArchiveIO:
     def __init__(self, file, mode, compression="store"):
@@ -9,13 +9,19 @@ class ArchiveIO:
             "deflate": zipfile.ZIP_DEFLATED,
             "bzip2": zipfile.ZIP_BZIP2,
             "lzma": zipfile.ZIP_LZMA,
-            "store": zipfile.ZIP_STORED
+            "store": zipfile.ZIP_STORED,
+            "xz": zipfile.ZIP_XZ,
         }
 
-        self._compression = compression_map.get(compression.lower(), zipfile.ZIP_STORED)
+        if compression.lower() not in compression_map:
+            raise ValueError(f"Unsupported compression: {compression}")
+
+        self._compression = compression_map[compression.lower()]
 
         try:
             self._archive = zipfile.ZipFile(file, mode, compression=self._compression)
+        except NotImplementedError as e:
+            raise ValueError(f"LZMA compression not supported in your Python build: {e}")
         except Exception as e:
             raise ValueError(f"Failed to open the archive: {e}")
 
